@@ -276,7 +276,7 @@ class RESTClient(RESTAssertion):
                                             timeout=request_timeout)
 
         except BaseException as err:
-            logger.error(err)
+            logger.exception('Something wend wrong.')
             raise err
 
         return response
@@ -289,6 +289,7 @@ class RESTClient(RESTAssertion):
             response = requests.get(self.base_url, timeout=10, verify=False)
             if response.status_code == 200:
                 return True
+            return False
         except requests.exceptions.Timeout:
             return False
         except requests.exceptions.ConnectionError:
@@ -398,7 +399,7 @@ class RESTClient(RESTAssertion):
             return False if result else True
 
     def is_service_initialized(self, timeout: Union[int, float] = 20) -> bool:
-        """GET https://{IP}:{PORT}
+        """Send GET to base URL https://{IP}:{PORT}
 
         :param timeout:
         :return:
@@ -442,18 +443,23 @@ class AuthToken:
 
     @property
     def token(self):
-        if self.client.is_service_available:
-            try:
-                response = requests.post(self.auth_url, json=self.client.auth_payload, verify=False, timeout=7)
-                return response.json()['token']
-            except json.decoder.JSONDecodeError as err:
-                logger.error(err)
-                logger.info(f'Login URL: {self.auth_url}')
-                logger.info(self.client.auth_payload)
-                return 'Cannot get token property: {}'.format(err)
-            except TypeError as err:
-                logger.error(err)
-                return 'Endpoint is available but "token" key cannot be retrieved.\n' \
-                       'Check credentials.\n{}'.format(err)
-        else:
-            return f'Host {self.client.host} is unreachable. Check service status'
+        """Get token"""
+
+        response_json = None
+
+        try:
+            response = requests.post(self.auth_url, json=self.client.auth_payload, verify=False, timeout=7)
+            response_json = response.json()
+            return response_json['token']
+        except KeyError as err:
+            logger.exception(f'Cannot get key (token) from json data. {response_json}')
+            raise err
+        except json.decoder.JSONDecodeError as err:
+            logger.exception(f'Cannot get token property. URL: {self.auth_url} ({self.client.auth_payload})')
+            raise err
+        except TypeError as err:
+            logger.exception('Endpoint is available but "token" key cannot be retrieved.')
+            raise err
+        except requests.exceptions.ConnectTimeout as err:
+            logger.exception(f'Perhaps, URI ({self.auth_url}) or service is unreachable.')
+            raise err
